//! All operator related types and traits for building queries
//!
//! [``Arithmetic``], [``Comparison``] and [``Logical``] traits can be brought into scope to enable
//! binary operators of the respective type on the base query types such as
//! [``super::Metric``] and [``super::Scalar``].
//!
//! # Example
//! ```
//! use mquery::query::{
//!     ops::{Arithmetic, Comparison},
//!     Metric, Scalar,
//! };
//!
//! let _ = Metric::new("target_metric")
//!     .add(Metric::new("second_metric"))
//!     .mul(Scalar(0.5))
//!     .cmp_eq_bool(Metric::new("third_metric"));
//! ```

use crate::seal::Sealed;
use std::fmt::Display;

mod arith;
mod cmp;
mod logic;
pub(crate) mod modifiers;

pub use arith::Arithmetic;
pub use cmp::Comparison;
pub use logic::Logical;

/// Marker trait for signifying that a type can be used with the operators
pub trait Operable: Display + Sealed {}

impl<T: Operable> Operable for &T {}
impl<T: Operable> Operable for &mut T {}
